%global gitname     IPMITOOL
%global gitversion  1_8_19

Summary:	Utility for interfacing with IPMI devices
Name:		ipmitool
Version:	1.8.19
Release:	%mkrel 1
License:	GPLv2
Group:		System/Kernel and hardware
Url:		https://github.com/ipmitool/ipmitool
Source0:	https://github.com/%{name}/%{name}/archive/%{gitname}_%{gitversion}/%{name}-%{version}.tar.gz
Source1:	openipmi-ipmievd.sysconf
Source2:	ipmievd.service
# https://www.iana.org/assignments/enterprise-numbers.txt
Source7:	enterprise-numbers

# https://github.com/ipmitool/ipmitool/issues/170
Patch3:		ipmitool-1.8.19-set-kg-key.patch
Patch4:		0004-slowswid.patch
Patch5:		0005-sensor-id-length.patch
Patch7:		0007-check-input.patch
# https://github.com/ipmitool/ipmitool/issues/199
# https://github.com/ipmitool/ipmitool/pull/214 - approved but not merged
Patch14:	0014-lanplus-cipher-retry.patch

# Debian patches, never applied upstream
# https://bugs.launchpad.net/ubuntu/+source/ipmitool/+bug/633054
# https://sourceforge.net/p/ipmitool/mailman/message/24405281/
Patch100:	0100-fix_buf_overflow.patch
# https://sourceforge.net/p/ipmitool/bugs/490/
Patch105:	0105-sensor_reading.patch

BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(readline)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	automake
BuildRequires:	autoconf
BuildRequires:	libtool

%description
IPMI stands for Intelligent Platform Management Interface
and is an open standard for machine health, and (remote) control
and is implemented by many hardware vendors - Intel is one of the originators,
and early adopters of the standard.
This package contains a utility for interfacing with IPMI-enabled devices
through either the OpenIPMI kernel driver or with IPMI-over-LAN protocol.
These functions include printing FRU(Field Replaceable Unit) information,
LAN configuration, sensor readings, and remote chassis power control.

%prep
%autosetup -p1 -n %{name}-%{gitname}_%{gitversion}

%build
# --disable-dependency-tracking speeds up the build
# --enable-file-security adds some security checks
# --disable-intf-free disables FreeIPMI support - we don't want to depend on
#   FreeIPMI libraries, FreeIPMI has its own ipmitoool-like utility.

autoreconf -vfi

install -Dm 644 %{SOURCE7} .
%configure \
    --disable-dependency-tracking \
    --enable-file-security \
    --disable-intf-free \
    --enable-intf-usb
%make_build

%install
%make_install

rm -rf %{buildroot}%{_datadir}/doc/ipmitool
install -Dpm 644 %{SOURCE2} %{buildroot}%{_unitdir}/ipmievd.service
install -Dpm 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/ipmievd

%post
%_post_service ipmievd

%preun
%_preun_service ipmievd

%files
%doc AUTHORS README
%license COPYING
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man8/*
%{_datadir}/ipmitool/
%config(noreplace) %{_sysconfdir}/sysconfig/ipmievd
%{_unitdir}/ipmievd.service
%{_datadir}/misc/enterprise-numbers


%changelog
* Wed Mar 06 2024 daviddavid <daviddavid> 1.8.19-1.mga10
+ Revision: 2047889
- new version: 1.8.19

* Thu Apr 06 2023 ns80 <ns80> 1.8.18-10.mga9
+ Revision: 1951558
- replace partial fix for CVE-2020-5208 with patches from Ubuntu (mga#31759)

* Fri Mar 18 2022 umeabot <umeabot> 1.8.18-9.mga9
+ Revision: 1797874
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 1.8.18-8.mga9
+ Revision: 1747892
- rebuild for openssl 3.0.0

* Sat Oct 24 2020 akien <akien> 1.8.18-7.mga8
+ Revision: 1639076
- Fix build with GCC 10

* Thu Feb 20 2020 daviddavid <daviddavid> 1.8.18-6.mga8
+ Revision: 1545820
- add/rebase upstream patches to fix CVE-2020-5208 (mga#26218)
- do not mark man pages as doc
- update URL
- switch pid dir from /var/run to /run

* Tue Feb 18 2020 umeabot <umeabot> 1.8.18-5.mga8
+ Revision: 1542178
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1.8.18-4.mga8
+ Revision: 1475969
- rebuild for readline

* Sun Sep 23 2018 umeabot <umeabot> 1.8.18-3.mga7
+ Revision: 1298309
- Mageia 7 Mass Rebuild

* Tue Jan 02 2018 wally <wally> 1.8.18-2.mga7
+ Revision: 1189442
- rebuild for new readline

* Mon Sep 11 2017 guillomovitch <guillomovitch> 1.8.18-1.mga7
+ Revision: 1152707
- new version 1.8.18
- fix build with openssl 1.1

* Thu Feb 11 2016 umeabot <umeabot> 1.8.15-2.mga6
+ Revision: 954448
- Mageia 6 Mass Rebuild

* Sat Jul 25 2015 philippem <philippem> 1.8.15-1.mga6
+ Revision: 857613
- update to 1.8.15

* Wed Oct 15 2014 umeabot <umeabot> 1.8.14-3.mga5
+ Revision: 742281
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.8.14-2.mga5
+ Revision: 680540
- Mageia 5 Mass Rebuild

* Mon Jun 16 2014 philippem <philippem> 1.8.14-1.mga5
+ Revision: 637634
- update to 1.8.14

* Tue Oct 29 2013 philippem <philippem> 1.8.13-1.mga4
+ Revision: 547876
- imported package ipmitool

